function SLFtoolbox = tbx_cfg_SLFtoolbox
% SLF refills white matter lesions with the mean and half of the standard
%     deviation of the WM tissue of the input image.
%
%
%     This program is free software: you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation, either version 3 of the License, or
%     (at your option) any later version.
% 
%     This program is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%   Copyright 2014 Sergi Valverde/Arnau Oliver/ Xavier Lladó
%   $Revision: 1.0$     $Date: 12/03/14$ 
%===============================================================================


% ---------------------------------------------------------------------
% MENU 1: WM LESION-FILLING on T1-w images
% ---------------------------------------------------------------------

% T1 image 

data_T1 = cfg_files;
data_T1.tag  = 'data_T1';
data_T1.name = 'T1 volume to refill';
data_T1.help = {'Select T1-w scans for processing. When more than one scan is processed, this assumes that there is one scan for each subject. The same order of subjects must be followed between T1-w input scans and their corresponding brain masks, and lesion masks.'};
data_T1.filter = 'image';
data_T1.ufilter = '.*';
data_T1.num     = [1 Inf];

% Brain Mask

data_BrainMask = cfg_files;
data_BrainMask.tag  = 'data_BrainMask';
data_BrainMask.name = 'Binary brainmask volume';
data_BrainMask.help = {'Select binary brain masks for processing. When more than one scan is processed, this assumes that there is one scan for each subject. The same order of subjects must be followed between T1-w input scans and their corresponding brain masks, and lesion masks.'};
data_BrainMask.filter = 'image';
data_BrainMask.ufilter = '.*';
data_BrainMask.num     = [1 Inf];

% Lesion image

data_LesionMask = cfg_files;
data_LesionMask.tag  = 'data_LesionMask';
data_LesionMask.name = 'Lesion mask binary volume';
data_LesionMask.help = {'Select binary lesion masks for processing. When more than one scan is processed, this assumes that there is one scan for each subject. Lesion masks must be in the same space than thes T1-w image. The same order of subjects must be followed between T1-w input scans and their corresponding brain masks, and lesion masks.'};
data_LesionMask.filter = 'image';
data_LesionMask.ufilter = '.*';
data_LesionMask.num     = [1 Inf];

% ---------------------------------------------------------------------
% Lesion Filling process
% ---------------------------------------------------------------------
lesionFilling         = cfg_exbranch;
lesionFilling.tag     = 'lesionFilling';
lesionFilling.name    = 'WM lesion-filling toolbox';
lesionFilling.val     = {data_T1 data_BrainMask data_LesionMask};
lesionFilling.help    = {['This toolbox can be useful to refill WM lesions with signal intensities similar to normal WM.',...
                          ' Basically, for each slice composing the three-dimensional image, lesion voxel intensities are replaced by random intensities of a normal distribution generated from the mean normal WM intensity of the current slice',...
                          ' The proposed algorithm requires three input images: a preprocessed T1-w image (intensity inhomogeneity corrected) and its corresponding binary brainmask, and WM lesion mask.',...
                          ' WM lesions are masked out from the T1-w image using the provided lesion mask, in order to avoid the influence of artificial lesions on tissue distributions. The resulting image is used to estimate the probability of each voxel to be classified as CSF, GM, and NAWM, by segmenting tissue with a Fuzzy-C-means approach. From the obtained tissue segmentation output,  we compute the three-dimensional NAWM mask from the image voxels with the highest probability to pertain to the WM cluster.',...
                          ' Finally, the lesion-filling process is achieved as follows: for each slice composing the three-dimensional image, we compute the mean and standard deviation of the signal intensity of NAWM tissue. These values are used to generate a normal distribution with mean equal to the computed NAWM mean intensity and standard deviation equal to half of the computed NAWM standard deviation. Lesion voxels intensities from the current image slice are replaced by random values of the generated distribution. The procedure is repeated until all image slices are completed.']};
                      
lesionFilling.prog    = @SLF_lesion_filling;


 








 SLFtoolbox  = cfg_choice;
 SLFtoolbox.name = 'SLFtoolbox';
 SLFtoolbox.tag  = 'SLFtoolbox';
 % menu d'entrada inicial 
 SLFtoolbox.values = {lesionFilling};

